@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 
 import ConfigParser
 import argparse
@@ -5,6 +6,8 @@ import os.path
 import warnings
 import re
 import sre_constants
+import subprocess
+from string import Formatter
 
 def attempt_version_bump(args):
     try:
@@ -24,7 +27,17 @@ def attempt_version_bump(args):
 
     parsed = match.groupdict()
 
-    parsed[args.bump] = int(parsed[args.bump]) + 1
+    order = (label for _, label, _, _ in Formatter().parse(args.serialize))
+
+    bumped = False
+    for label in order:
+        if label == args.bump:
+            parsed[args.bump] = int(parsed[args.bump]) + 1
+            bumped = True
+        elif bumped:
+            parsed[label] = 0
+
+    assert bumped
 
     try:
         return args.serialize.format(**parsed)
@@ -94,6 +107,13 @@ def main(args=None):
     parser3.add_argument('--new-version', metavar='VERSION',
         help='New version that should be in the files',
         required=not 'new_version' in defaults)
+    parser3.add_argument('--commit', action='store_true',
+        help='Create a commit in version control')
+    parser3.add_argument('--tag', action='store_true',
+        help='Create a tag in version control')
+    parser3.add_argument('--message', '-m', metavar='COMMIT_MSG',
+        help='Commit message',
+        default='Bump version: {current_version} → {new_version}')
 
     files = []
     if 'files' in defaults:
@@ -109,6 +129,16 @@ def main(args=None):
     if len(args.files) is 0:
         warnings.warn("No files specified")
 
+    if os.path.isdir(".git"):
+        lines = [
+            line.strip() for line in
+            subprocess.check_output(["git", "status", "--porcelain"]).splitlines()
+            if not line.strip().startswith("??")
+        ]
+
+        if lines:
+            assert False, "Git working directory not clean:\n{}".format("\n".join(lines))
+
     for path in args.files:
         with open(path, 'r') as f:
             before = f.read()
@@ -122,10 +152,27 @@ def main(args=None):
             with open(path, 'w') as f:
                 f.write(after)
 
+
+    commit_files = args.files
+
     if config:
         config.remove_option('bumpversion', 'new_version')
         config.set('bumpversion', 'current_version', args.new_version)
 
         if not args.dry_run:
             config.write(open(known_args.config_file, 'wb'))
+            commit_files.append(known_args.config_file)
+
+    if args.commit:
+        if not args.dry_run:
+            for path in commit_files:
+                subprocess.check_call(["git", "add", path])
+
+            subprocess.check_call(["git", "commit", "-m", args.message.format(
+                current_version=args.current_version,
+                new_version=args.new_version,
+                )])
+
+            subprocess.check_call(["git", "tag", "v{new_version}".format(
+                new_version=args.new_version)])
 
